// Case for HelderHiFi amplifier, power supply, and speakers. 2013-03-27, nerdfever.com

// GENERAL CONSTANTS

slop = (1/16);			// inches
PartAlpha = 0.5;

// COMPONENT DIMENSIONS

AmpH = 1.75;
AmpW = 2;
AmpD = 5;

SpeakerW = 4.5;
SpeakerH = 7.25;
SpeakerD = 4.5;

BatteryW = 3.5;
BatteryH = 2.75;
BatteryD = 4;

PowerW = 3.35;
PowerH = 2;
PowerD = 3.5;

// PARTS DIMENSIONS - INPUTS

Thick = 3/4;			// for load-bearing base, top, supports
ShelfThick = 1/4;
StripThick = 1/8; 			

StripLip = 1/4;

TopW = 8.5;

PlateThick = StripThick;

// PARTS DIMENSIONS - CALCULATED

BaseW = slop + SpeakerW + slop + Thick + slop + BatteryW + slop + Thick + slop + SpeakerW + slop;
BaseH = Thick;
BaseD = max(max(max(AmpD, SpeakerD), BatteryD), PowerD) - 2*StripThick;

StripH = BaseH + StripLip;

ShelfW = BatteryW + 2*slop;
ShelfD = BaseD;

ShelfX = BaseW/2 - ShelfW/2;
Shelf1Y = StripH + BatteryH + slop;
Shelf2Y = Shelf1Y + ShelfThick + StripLip + PowerH + slop;

TopD = BaseD + 2*StripThick;

TopX = BaseW/2-TopW/2;
TopY = Shelf2Y + ShelfThick + AmpH;
TopZ = -StripThick;

PowerStripH = ShelfThick + StripLip;

PlateH = Shelf2Y - StripH + ShelfThick;

// FUNCTIONS

module part(name, w, h, d) {
	cube ([w, h, d]); 
	echo (name, w, h, d);
}

// PARTS

module battery(x,y,z) 	{ translate([x,y,z]) { color("Grey", PartAlpha)	 	{cube ([BatteryW, BatteryH, BatteryD]);} } }
module speaker(x,y,z) 	{ translate([x,y,z]) { color("Black", PartAlpha)    	{cube ([SpeakerW, SpeakerH, SpeakerD]); } } }
module amplifier(x,y,z)	{ translate([x,y,z]) { color("Blue",  PartAlpha)    	{cube ([AmpW, AmpH, AmpD]); } } }
module power(x,y,z) 	{ translate([x,y,z]) { color("Maroon", PartAlpha)	{cube ([PowerW, PowerH, PowerD]); } } }

module base(x,y,z) 		{ translate([x,y,z]) { part("Base", BaseW, BaseH, BaseD); } }
module top(x,y,z)		{ translate([x,y,z]) { part("Top", TopW,  BaseH, TopD); } }
module longStrip(x,y,z)	{ translate([x,y,z]) { part("Long strip", BaseW+2*StripThick, StripH, StripThick); } }
module shortStrip(x,y,z)	{ translate([x,y,z]) { part("Short strip", StripThick, StripH, BaseD); } }

module shelf1(x,y,z)		{ translate([x,y,z]) { part("Shelf1", ShelfW, ShelfThick, ShelfD); } }
module shelf2(x,y,z)		{ translate([x,y,z]) { part("Shelf2", ShelfW, ShelfThick, ShelfD+StripThick); } }
module powerStrip(x,y,z)	{ translate([x,y,z]) { part("Power strip", ShelfW, PowerStripH, StripThick); } }

module plate(x,y,z)		{ translate([x,y,z]) { part("Plate", ShelfW + 2*Thick, PlateH, PlateThick); } }

module pillar(x,y,z) { 
	translate([x,y,z]) {
		difference() {
			part("Pillar (less subtraction)", Thick, TopY-BaseH, TopD);

			translate([0,0,0]) { 
				cube([Thick, StripLip, StripThick]); 					// remove back bottom corner (room for strip)
				echo("Pillar remove", StripLip, StripThick);
			}
 	
			translate([0,0,TopD-StripThick]) {
				cube([Thick, Shelf2Y+ShelfThick-BaseH, StripThick]);	// remove front to make room for strip & plate
				echo("Pillar remove", Shelf2Y+ShelfThick-BaseH, StripThick);
			}
		}
	} 
}



// DRAW

base(0,0,0);
longStrip(-StripThick, 0, -StripThick);					// front strip
longStrip(-StripThick, 0, BaseD);						// back strip
shortStrip(-StripThick, 0, 0);							// left strip
shortStrip(BaseW, 0, 0);								// right strip

pillar(ShelfX-Thick, BaseH, -StripThick);				// left pillar
pillar(ShelfX+ShelfW, BaseH, -StripThick);				// right pillar

shelf1(ShelfX, Shelf1Y, 0);							// bottom shelf (power)
shelf2(ShelfX, Shelf2Y , -StripThick);					// top shelf (amp)
powerStrip(ShelfX, Shelf1Y, -StripThick);

plate(ShelfX - Thick, StripH, ShelfD);

top(TopX, TopY, TopZ);


speaker(slop, BaseH, slop);							// left speaker
speaker(BaseW - SpeakerW - slop, BaseH, slop); 		// right speaker

battery(BaseW/2-BatteryW/2, BaseH, 0);

amplifier(BaseW/2-AmpW/2, Shelf2Y+ShelfThick, -StripThick);

power(BaseW/2-PowerW/2, Shelf1Y+ShelfThick, 0);

// REPORT RESULTS

echo("Clearance for speakers above lip", TopY - (BaseH+StripLip) - SpeakerH);
